PlatformInfo class abstract final

Platform helpers used by shared framework code.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

current LarkPlatform
The currently detected runtime platform.
no setter
isServer bool
Whether the current runtime is a server (Dart VM) environment.
no setter
isTest bool
Whether the current runtime is running under tests.
no setter
isWeb bool
Whether the current runtime is a browser/web environment.
no setter