AlignItems enum
Values for align-items property.
Values
- stretch → const AlignItems
-
const AlignItems('stretch') - center → const AlignItems
-
const AlignItems('center') - flexStart → const AlignItems
-
const AlignItems('flex-start') - flexEnd → const AlignItems
-
const AlignItems('flex-end') - baseline → const AlignItems
-
const AlignItems('baseline') - start → const AlignItems
-
const AlignItems('start') - end → const AlignItems
-
const AlignItems('end') - selfStart → const AlignItems
-
const AlignItems('self-start') - selfEnd → const AlignItems
-
const AlignItems('self-end') - initial → const AlignItems
-
const AlignItems('initial') - inherit → const AlignItems
-
const AlignItems('inherit')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AlignItems> - A constant List of the values in this enum, in order of their declaration.