AnimationFillMode enum

Values for animation-fill-mode property.

Inheritance
Available extensions

Values

none → const AnimationFillMode
const AnimationFillMode('none')
forwards → const AnimationFillMode
const AnimationFillMode('forwards')
backwards → const AnimationFillMode
const AnimationFillMode('backwards')
both → const AnimationFillMode
const AnimationFillMode('both')
initial → const AnimationFillMode
const AnimationFillMode('initial')
inherit → const AnimationFillMode
const AnimationFillMode('inherit')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AnimationFillMode>
A constant List of the values in this enum, in order of their declaration.