AppConfig class

Application configuration loaded from environment.

Constructors

AppConfig({required String name, String? baseUrl, String? apiUrl, int port = 3000, bool debug = false})
AppConfig.fromEnv()
Load config from environment.
factory

Properties

apiUrl String?
final
baseUrl String?
final
debug bool
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
port int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited