DevMessageType enum

Types of dev messages.

Inheritance
Available extensions

Values

fullReload → const DevMessageType

Full page reload required.

hotReload → const DevMessageType

Hot reload with state preservation.

hotRestart → const DevMessageType

Hot restart (reset state but no full reload).

componentUpdate → const DevMessageType

Single component needs re-render.

styleUpdate → const DevMessageType

CSS injection without page reload.

routeUpdate → const DevMessageType

Route definition changed.

storeUpdate → const DevMessageType

Store definition changed.

contentUpdate → const DevMessageType

Content file changed (markdown, etc).

devtoolsConnect → const DevMessageType

DevTools panel connected.

devtoolsDisconnect → const DevMessageType

DevTools panel disconnected.

stateSnapshot → const DevMessageType

Request for full state snapshot.

componentTree → const DevMessageType

Request for component tree.

componentTreeResponse → const DevMessageType

Component tree response.

stateEdit → const DevMessageType

State edit request from DevTools.

highlightComponent → const DevMessageType

Highlight component request.

clearHighlight → const DevMessageType

Clear component highlight.

buildError → const DevMessageType

Build/compilation error.

runtimeError → const DevMessageType

Runtime error.

clearErrors → const DevMessageType

Clear error overlay.

metrics → const DevMessageType

Performance metrics update.

networkRequest → const DevMessageType

Network request captured.

timelineEvent → const DevMessageType

Timeline event.

ready → const DevMessageType

Ready signal from client.

ping → const DevMessageType

Ping/pong for connection health.

pong → const DevMessageType

Pong response.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DevMessageType>
A constant List of the values in this enum, in order of their declaration.