FontStretch enum

Values for font-stretch property.

Inheritance
Available extensions

Values

ultraCondensed → const FontStretch
const FontStretch('ultra-condensed')
extraCondensed → const FontStretch
const FontStretch('extra-condensed')
condensed → const FontStretch
const FontStretch('condensed')
semiCondensed → const FontStretch
const FontStretch('semi-condensed')
normal → const FontStretch
const FontStretch('normal')
semiExpanded → const FontStretch
const FontStretch('semi-expanded')
expanded → const FontStretch
const FontStretch('expanded')
extraExpanded → const FontStretch
const FontStretch('extra-expanded')
ultraExpanded → const FontStretch
const FontStretch('ultra-expanded')
initial → const FontStretch
const FontStretch('initial')
inherit → const FontStretch
const FontStretch('inherit')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FontStretch>
A constant List of the values in this enum, in order of their declaration.