FontVariant enum

Values for font-variant property.

Inheritance
Available extensions

Values

normal → const FontVariant
const FontVariant('normal')
smallCaps → const FontVariant
const FontVariant('small-caps')
allSmallCaps → const FontVariant
const FontVariant('all-small-caps')
petiteCaps → const FontVariant
const FontVariant('petite-caps')
allPetiteCaps → const FontVariant
const FontVariant('all-petite-caps')
unicase → const FontVariant
const FontVariant('unicase')
titlingCaps → const FontVariant
const FontVariant('titling-caps')
initial → const FontVariant
const FontVariant('initial')
inherit → const FontVariant
const FontVariant('inherit')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FontVariant>
A constant List of the values in this enum, in order of their declaration.