GoogleFont class

Configuration for a single Google Font.

Constructors

GoogleFont({required String family, List<FontWeight> weights = const [FontWeight.w400], bool italic = false})
const

Properties

family String
Font family name (e.g., 'Geist', 'Roboto').
final
hashCode int
The hash code for this object.
no setterinherited
italic bool
Include italic variants.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
weights List<FontWeight>
Font weights to include.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toApiParam() String
Generates the Google Fonts API parameter for this font.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited