Head class

Head configuration object for LarkApp.

LarkApp(
  head: Head(title: 'My App'),
)

Constructors

Head({String? title, List<MetaEntry> meta = const [], List<LinkEntry> link = const []})

Properties

allTags List<HeadEntry>
Convert to list of HeadEntries.
no setter
hashCode int
The hash code for this object.
no setterinherited
Link entries (stylesheets, icons, etc).
final
meta List<MetaEntry>
Meta entries.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
Page title.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited