key property
Unique identifier for deduplication. Tags with the same key from higher layers override lower layers.
Implementation
final String key;
Unique identifier for deduplication. Tags with the same key from higher layers override lower layers.
final String key;