HeadLayer enum

Priority layers for tag resolution. Higher priority layers override lower ones for tags with the same key.

Inheritance
Available extensions

Values

app → const HeadLayer

App-level defaults from LarkConfig.

route → const HeadLayer

Route-level config from @RouteMeta or route configuration.

component → const HeadLayer

Component-level from useMeta/useHead/useSeo calls.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<HeadLayer>
A constant List of the values in this enum, in order of their declaration.