LarkConfig class

Lark application configuration.

All Lark apps use universal rendering:

  • Static generation for non-dynamic routes (SSG)
  • Server-side rendering for dynamic routes (SSR)
  • Client-side hydration after first load

Constructors

LarkConfig({required String name, String baseUrl = '/', String version = '1.0.0', BuildConfig build = const BuildConfig(), TailwindConfig tailwind = const TailwindConfig(), List<GoogleFont> fonts = const [], List<String> ssgRoutes = const []})
const

Properties

baseUrl String
API base URL.
final
build BuildConfig
Build options.
final
fonts List<GoogleFont>
Google Fonts to include.
final
hashCode int
The hash code for this object.
no setterinherited
name String
App name (used in meta tags).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ssgRoutes List<String>
Additional routes to pre-render as static HTML.
final
tailwind TailwindConfig
Tailwind configuration.
final
version String
App version.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited