MenuController class

Menu visibility controller.

Constructors

Properties

hashCode int
The hash code for this object.
no setterinherited
isOpen bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state Ref<bool>
final

Methods

close() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
open() → void
toggle() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited