PerformanceMetrics class

Performance metrics collector.

Constructors

PerformanceMetrics()

Properties

averageBuildTimes Map<String, Duration>
Average build time per component.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slowestBuilds List<MapEntry<String, Duration>>
Slowest builds.
no setter
totalBuilds int
Total build count.
no setter
totalEffects int
Total effect runs.
no setter

Methods

clear() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited