QueryKey typedef

QueryKey = List<Object?>

A query key uniquely identifies cached data.

Keys are arrays that can contain primitives or serializable objects. The entire array is used for exact matching in the cache.

// Simple key
['users']

// Key with ID parameter
['users', userId]

// Key with filters
['todos', {'status': 'active', 'page': 1}]

Implementation

typedef QueryKey = List<Object?>;