RouteCollection class
Route collection for matching.
Constructors
-
RouteCollection(List<
RouteDefinition> routes)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
routes
→ List<
RouteDefinition> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
findByName(
String name) → RouteDefinition? - Finds a route by name.
-
generatePath(
String name, [Map< String, String> ? params]) → String? - Generates a path from a named route with params.
-
match(
String path) → RouteMatch? - Finds the first matching route for a path.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited