ThemeColors class

Color tokens for theming.

Constructors

ThemeColors({Color primary = const Color(0xFF3B82F6), Color secondary = const Color(0xFF6366F1), Color background = const Color(0xFFFFFFFF), Color surface = const Color(0xFFF3F4F6), Color text = const Color(0xFF1F2937), Color textSecondary = const Color(0xFF6B7280), Color border = const Color(0xFFE5E7EB), Color error = const Color(0xFFEF4444), Color success = const Color(0xFF22C55E), Color warning = const Color(0xFFF59E0B)})
const

Properties

background Color
final
border Color
final
error Color
final
hashCode int
The hash code for this object.
no setterinherited
primary Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary Color
final
success Color
final
surface Color
final
text Color
final
textSecondary Color
final
warning Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited