ThemeShadows class

Shadow tokens.

Constructors

ThemeShadows({String sm = '0 1px 2px rgba(15, 23, 42, 0.08)', String md = '0 8px 16px rgba(15, 23, 42, 0.12)', String lg = '0 16px 40px rgba(15, 23, 42, 0.16)', String xl = '0 24px 60px rgba(15, 23, 42, 0.20)'})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
lg String
final
md String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sm String
final
xl String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited