WordBreak enum

Values for word-break property.

Inheritance
Available extensions

Values

normal → const WordBreak
const WordBreak('normal')
breakAll → const WordBreak
const WordBreak('break-all')
keepAll → const WordBreak
const WordBreak('keep-all')
breakWord → const WordBreak
const WordBreak('break-word')
initial → const WordBreak
const WordBreak('initial')
inherit → const WordBreak
const WordBreak('inherit')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<WordBreak>
A constant List of the values in this enum, in order of their declaration.