NoOpStorageBinding class

No-op storage binding using memory storage.

Implemented types

Constructors

NoOpStorageBinding()

Properties

hashCode int
The hash code for this object.
no setterinherited
local PlatformStorage
Local storage (persists across sessions).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
session PlatformStorage
Session storage (cleared when session ends).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited