PlatformStorage class abstract

Abstract storage interface.

Implementers

Constructors

PlatformStorage()

Properties

hashCode int
The hash code for this object.
no setterinherited
keys Iterable<String>
Get all keys.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
Clear all values.
get(String key) String?
Get a value by key.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key) → void
Remove a value.
set(String key, String value) → void
Set a value.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited