BuildConfig class
Build configuration.
Constructors
- BuildConfig({String output = 'build', bool sourceMaps = true, bool minify = true})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- minify → bool
-
Minify in production.
final
- output → String
-
Output directory.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceMaps → bool
-
Generate source maps.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited