GridAutoFlow enum
Values for grid-auto-flow property.
Values
- row → const GridAutoFlow
-
const GridAutoFlow('row') - column → const GridAutoFlow
-
const GridAutoFlow('column') - dense → const GridAutoFlow
-
const GridAutoFlow('dense') - rowDense → const GridAutoFlow
-
const GridAutoFlow('row dense') - columnDense → const GridAutoFlow
-
const GridAutoFlow('column dense') - initial → const GridAutoFlow
-
const GridAutoFlow('initial') - inherit → const GridAutoFlow
-
const GridAutoFlow('inherit')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
GridAutoFlow> - A constant List of the values in this enum, in order of their declaration.