Image class
Displays an image.
Constructors
Properties
- alt → String?
-
final
- css → String?
-
Component-level CSS styles.
no setterinherited
- fit → ImageFit
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- isDirty → bool
-
Whether this component needs rebuild.
no setterinherited
- isMounted → bool
-
Whether this component is mounted.
no setterinherited
- key → Object?
-
Unique identifier for this component within its parent.
finalinherited
- mounted → bool
-
Whether this component is mounted (alias for isMounted).
no setterinherited
- onNeedRebuild ← RebuildCallback?
-
Sets the rebuild callback.
no getterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scopeId → String
-
Unique identifier for CSS scoping.
no setterinherited
- src → String
-
final
-
styleSheet
→ Map<
String, Style> -
Component-level scoped styles using typed records.
no setterinherited
- width → double?
-
final
Methods
-
build(
) → Component -
Builds the component's content.
override
-
clearDirty(
) → void -
Clears the dirty flag.
inherited
-
layout(
) → Component? -
The layout wrapper for this component.
inherited
-
markDirty(
) → void -
Marks this component as needing rebuild.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onMount(
) → void -
Called when mounted to the tree.
inherited
-
onUnmount(
) → void -
Called before removal from tree.
inherited
-
registerEffect(
CleanupFn? effectFn()) → void -
Registers an effect disposed on unmount.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited