ListStyleType enum
Values for list-style-type property.
Values
- disc → const ListStyleType
-
const ListStyleType('disc') - circle → const ListStyleType
-
const ListStyleType('circle') - square → const ListStyleType
-
const ListStyleType('square') - decimal → const ListStyleType
-
const ListStyleType('decimal') - decimalLeadingZero → const ListStyleType
-
const ListStyleType('decimal-leading-zero') - lowerRoman → const ListStyleType
-
const ListStyleType('lower-roman') - upperRoman → const ListStyleType
-
const ListStyleType('upper-roman') - lowerGreek → const ListStyleType
-
const ListStyleType('lower-greek') - lowerLatin → const ListStyleType
-
const ListStyleType('lower-latin') - upperLatin → const ListStyleType
-
const ListStyleType('upper-latin') - armenian → const ListStyleType
-
const ListStyleType('armenian') - georgian → const ListStyleType
-
const ListStyleType('georgian') - lowerAlpha → const ListStyleType
-
const ListStyleType('lower-alpha') - upperAlpha → const ListStyleType
-
const ListStyleType('upper-alpha') - none → const ListStyleType
-
const ListStyleType('none') - initial → const ListStyleType
-
const ListStyleType('initial') - inherit → const ListStyleType
-
const ListStyleType('inherit')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ListStyleType> - A constant List of the values in this enum, in order of their declaration.