RefSnapshot class
Snapshot of a ref for DevTools display.
Constructors
- RefSnapshot({required String id, required String name, required dynamic value, required String type, required int subscriberCount, String? storeName, bool isDisposed = false})
-
const
- RefSnapshot.disposed()
-
Creates a disposed snapshot placeholder.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique ID.
final
- isDisposed → bool
-
Whether the ref has been disposed.
final
- name → String
-
Debug name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storeName → String?
-
Store name if part of a store.
final
- subscriberCount → int
-
Number of subscribers.
final
- type → String
-
Value type name.
final
- value → dynamic
-
Current value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited