ThemeTypography class
Typography tokens.
Constructors
-
ThemeTypography({String fontFamily = 'system-ui, sans-serif', String monoFamily = 'ui-monospace, SFMono-Regular, Menlo, Monaco, monospace', double xs = 12, double sm = 14, double md = 16, double lg = 18, double xl = 20, double xl2 = 24, double xl3 = 32, double xl4 = 40, double xl5 = 48, double xl6 = 56, double xl7 = 64, double xl8 = 96, double xl9 = 128, int weightRegular = 400, int weightMedium = 500, int weightSemiBold = 600, int weightBold = 700, Map<
String, String> custom = const {}}) -
const
Properties
-
custom
→ Map<
String, String> -
final
- fontFamily → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lg → double
-
final
- md → double
-
final
- monoFamily → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sm → double
-
final
- weightBold → int
-
final
- weightMedium → int
-
final
- weightRegular → int
-
final
- weightSemiBold → int
-
final
- xl → double
-
final
- xl2 → double
-
final
- xl3 → double
-
final
- xl4 → double
-
final
- xl5 → double
-
final
- xl6 → double
-
final
- xl7 → double
-
final
- xl8 → double
-
final
- xl9 → double
-
final
- xs → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited