NoOpNavigationBinding class
No-op navigation binding for server/test environments.
- Implemented types
Constructors
Properties
- currentHash → String
-
Gets current hash/fragment.
no setteroverride
- currentPath → String
-
Gets the current path from the platform.
no setteroverride
-
currentQuery
→ Map<
String, String> -
Gets current query parameters.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addPopStateListener(
void listener(String path)) → void -
Listen for navigation changes from the platform (e.g., back button).
override
-
back(
) → void -
Go back in history.
override
-
forward(
) → void -
Go forward in history.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
push(
String path) → void -
Push a new path to navigation stack.
override
-
removePopStateListener(
void listener(String path)) → void -
Remove a pop state listener.
override
-
replace(
String path) → void -
Replace the current path.
override
-
restoreScrollPosition(
) → void -
Restore scroll position for current path.
override
-
saveScrollPosition(
) → void -
Save current scroll position (for restoration on back/forward).
override
-
scrollToElement(
String elementId, {bool smooth = true}) → void -
Scroll to an element by ID (for hash navigation).
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited