RenderContext class
Render context for SSR.
Provides request-scoped data during server rendering.
- Available extensions
Constructors
Properties
-
Cookies from the request.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
Request headers.
final
- isMobile → bool
-
Check if request is from a mobile device (basic UA check).
no setter
- path → String
-
Request path (e.g., '/about').
final
-
query
→ Map<
String, String> -
Query parameters.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
- Get a specific cookie value.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited