ServerRenderer class abstract
Abstract server renderer interface.
Implementations provide async rendering with data collection.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
Component root, {required String path, Map< String, String> ? query, Map<String, String> ? headers}) → Future<RenderResult> - Render a component to HTML.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited