ComponentVNode class
A VNode representing a Lark Component.
Constructors
- ComponentVNode({required Component component, String? key})
Properties
-
attrs
→ Map<
String, String> -
finalinherited
-
children
→ List<
VNode> -
finalinherited
-
classes
→ List<
String> -
finalinherited
- component → Component
-
final
-
componentSignal
↔ Ref<
Component> ? -
getter/setter pair
- dispose ↔ void Function()?
-
getter/setter pair
- element ↔ Object?
-
The real DOM element this VNode is attached to.
getter/setter pairinherited
-
events
→ Map<
String, Function> -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- html → String?
-
finalinherited
-
inputFormatters
→ List<
InputFormatter> -
finalinherited
- key → String?
-
finalinherited
- onBlur → void Function(String)?
-
finalinherited
- onChanged → void Function(String)?
-
finalinherited
- onContextUpdate ↔ void Function(ComponentVNode)?
-
getter/setter pair
- onFocus → void Function(String)?
-
finalinherited
- onSubmit → void Function(String)?
-
finalinherited
- overlayConfig → OverlayConfig?
-
finalinherited
- portalContainer ↔ Object?
-
The detached container element if this is a portal.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollController → ScrollController?
-
finalinherited
-
styles
→ Map<
String, String> -
finalinherited
- subtree ↔ VNode?
-
getter/setter pair
- tag → String
-
finalinherited
- text → String?
-
finalinherited
- textInputAction → TextInputAction
-
finalinherited
- valueRef → Ref?
-
For two-way binding on input elements.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited