ComponentVNode class

A VNode representing a Lark Component.

Inheritance

Constructors

ComponentVNode({required Component component, String? key})

Properties

attrs Map<String, String>
finalinherited
children List<VNode>
finalinherited
classes List<String>
finalinherited
component Component
final
dispose ↔ void Function()?
getter/setter pair
element Object?
The real DOM element this VNode is attached to.
getter/setter pairinherited
events Map<String, Function>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
html String?
finalinherited
key String?
finalinherited
onChanged → void Function(String)?
finalinherited
onSubmit → void Function(String)?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styles Map<String, String>
finalinherited
subtree VNode?
getter/setter pair
tag String
finalinherited
text String?
finalinherited
valueRef Ref<String>?
For two-way binding on input elements.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited