VNode class
A virtual DOM node for efficient diffing.
- Implementers
Constructors
-
VNode({required String tag, String? text, String? html, Map<
String, String> ? attrs, Map<String, String> ? styles, List<String> ? classes, List<VNode> ? children, Map<String, Function> ? events, String? key, Ref? valueRef, List<InputFormatter> inputFormatters = const [], TextInputAction textInputAction = TextInputAction.done, ScrollController? scrollController, OverlayConfig? overlayConfig, void onChanged(String)?, void onFocus(String)?, void onBlur(String)?, void onSubmit(String)?})
Properties
-
attrs
→ Map<
String, String> -
final
-
children
→ List<
VNode> -
final
-
classes
→ List<
String> -
final
- element ↔ Object?
-
The real DOM element this VNode is attached to.
getter/setter pair
-
events
→ Map<
String, Function> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- html → String?
-
final
-
inputFormatters
→ List<
InputFormatter> -
final
- key → String?
-
final
- onBlur → void Function(String)?
-
final
- onChanged → void Function(String)?
-
final
- onFocus → void Function(String)?
-
final
- onSubmit → void Function(String)?
-
final
- overlayConfig → OverlayConfig?
-
final
- portalContainer ↔ Object?
-
The detached container element if this is a portal.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollController → ScrollController?
-
final
-
styles
→ Map<
String, String> -
final
- tag → String
-
final
- text → String?
-
final
- textInputAction → TextInputAction
-
final
- valueRef → Ref?
-
For two-way binding on input elements.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited