VNode class
A virtual DOM node for efficient diffing.
- Implementers
Constructors
Properties
-
attrs
→ Map<
String, String> -
final
-
children
→ List<
VNode> -
final
-
classes
→ List<
String> -
final
- element ↔ Object?
-
The real DOM element this VNode is attached to.
getter/setter pair
-
events
→ Map<
String, Function> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- html → String?
-
final
- key → String?
-
final
- onChanged → void Function(String)?
-
final
- onSubmit → void Function(String)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
styles
→ Map<
String, String> -
final
- tag → String
-
final
- text → String?
-
final
-
valueRef
→ Ref<
String> ? -
For two-way binding on input elements.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited